@@ -148,7 +148,12 @@ module Rabbit
                                    max_width, max_height|
           if (max_width and initial_width > max_width) or
               (max_height and initial_height > max_height)
-            scale = 0.95
+            scale = lambda do |_width, _height|
+              candidates = [0.95]
+              candidates << (max_width.to_f) / _width if max_width
+              candidates << (max_height.to_f) / _height if max_height
+              candidates.min
+            end
             compare = Proc.new do |_width, _height|
               (max_width.nil? or _width < max_width) and
                 (max_height.nil? or _height < max_height)
@@ -306,10 +311,16 @@ module Rabbit
 
         return if scale.nil? or compare.nil?
 
+        if scale.respond_to?(:call)
+          compute_scale = scale
+          scale = nil
+        end
+
         size = new_size = initial_font_size_for_compute_font_size
         current_layout_size = @layout.pixel_size
         unless compare.call(*@layout.pixel_size)
           loop do
+            scale = compute_scale.call(*@layout.pixel_size) if compute_scale
             new_size = compute_next_font_size(size, scale)
             break if new_size == size
             set_computed_font_size(new_size)
