@@ -1,3 +1,19 @@
+# Copyright (C) 2012-2016  Kouhei Sutou <kou@cozmixng.org>
+#
+# This program is free software; you can redistribute it and/or modify
+# it under the terms of the GNU General Public License as published by
+# the Free Software Foundation; either version 2 of the License, or
+# (at your option) any later version.
+#
+# This program is distributed in the hope that it will be useful,
+# but WITHOUT ANY WARRANTY; without even the implied warranty of
+# MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
+# GNU General Public License for more details.
+#
+# You should have received a copy of the GNU General Public License along
+# with this program; if not, write to the Free Software Foundation, Inc.,
+# 51 Franklin Street, Fifth Floor, Boston, MA 02110-1301 USA.
+
 require "English"
 
 require "rabbit/gettext"
@@ -156,7 +172,17 @@ module Rabbit
             if element.options[:transparent] and child_types == [:text]
               element.children.first.value.chomp!
             end
-            create_paragraph(convert_container(element))
+            converted_children = apply_class(convert_container(element),
+                                             element.attr["class"])
+            create_paragraph(converted_children)
+          end
+        end
+
+        def apply_class(children, klass)
+          return children if klass.nil?
+          classes = klass.split
+          classes.inject(children) do |nested_children, klass|
+            CustomTag.new(klass, nested_children)
           end
         end
 
@@ -177,7 +203,10 @@ module Rabbit
           waited_paragraphs = list_item.elements.find_all do |element|
             element.is_a?(Paragraph) and element.have_wait_tag?
           end
-          unless waited_paragraphs.empty?
+          if waited_paragraphs.empty?
+            list_item.default_visible = true
+            list_item.clear_theme
+          else
             waited_paragraphs.each do |paragraph|
               paragraph.default_visible = true
               paragraph.clear_theme
@@ -377,6 +406,18 @@ module Rabbit
           Ext::Inline.note(convert_container(element))
         end
 
+        def convert_tag(element)
+          name = element.attr["name"]
+          if name.nil?
+            raise ParseError, _("tag name is missing.")
+          end
+          if element.children.empty?
+            CustomTag.new(name)
+          else
+            CustomTag.new(name, convert_container(element))
+          end
+        end
+
         def convert_strikethrough(element)
           DeletedText.new(text(element.value))
         end
